"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const types = require("@babel/types");
/**
 * Represents a mutator which can remove the content of an array's elements.
 */
class ArrayDeclarationMutator {
    constructor() {
        this.name = 'ArrayDeclaration';
    }
    mutate(node) {
        if (types.isArrayExpression(node)) {
            return [
                // replace [...]
                node.elements.length
                    ? [node, { raw: '[]' }] // raw string here
                    : [node, { raw: '["Stryker was here"]' }]
            ];
        }
        else if ((types.isCallExpression(node) || types.isNewExpression(node)) && types.isIdentifier(node.callee) && node.callee.name === 'Array') {
            const newPrefix = types.isNewExpression(node) ? 'new ' : '';
            const mutatedCallArgs = node.arguments && node.arguments.length ? '' : '[]';
            return [[node, { raw: `${newPrefix}Array(${mutatedCallArgs})` }]];
        }
        else {
            return [];
        }
    }
}
exports.default = ArrayDeclarationMutator;
//# sourceMappingURL=ArrayDeclarationMutator.js.map